@@ -1,7 +1,7 @@
 use crate::model::error_proto::ErrorProto;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct JobStatus {
     #[serde(skip_serializing_if = "Option::is_none")]
